package com.jobs.controller;

import com.jobs.service.MinioService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.io.FilenameUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.Map;

@Api(tags = "Minio 操作接口")
@RestController
@RequestMapping("/minio")
public class MinioController {

    @Autowired
    private MinioService minioService;

    @ApiOperation("上传文件")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "path", value = "上传目录路径", required = false),
            @ApiImplicitParam(name = "file", value = "上传的目标文件",
                    dataType = "java.io.File", paramType = "query", required = true)})
    @PostMapping("/upload")
    //注意：针对 MultipartFile 需要增加 @RequestPart 注解，否则 knife4j 接口无法显示文件上传操作。
    public Map uploadFile(String path, @RequestPart("file") MultipartFile file) {
        String minioPath = minioService.uploadFile(path, file);
        Map<String, String> map = new HashMap<>();
        if (StringUtils.isNotBlank(minioPath)) {
            map.put("minio_path", minioPath);
            map.put("file_url", minioService.getFileFullUrl(minioPath));
        }
        return map;
    }

    //必须要加上 produces = "application/octet-stream" ，否则 knife4j 接口无法下载文件
    @ApiOperation(value = "下载文件", produces = "application/octet-stream")
    @ApiImplicitParam(name = "minioPath",
            value = "minio文件路径（不包含web域名和bucket名称）", required = true)
    @GetMapping("/download")
    public void downloadFile(String minioPath, HttpServletResponse response) {
        //获取文件名（包含后缀名）
        String fileName = FilenameUtils.getName(minioPath);
        byte[] bytes = minioService.downloadFile(minioPath);
        if (bytes != null) {
            try {
                //下载文件的响应类型，这里统一设置成了文件流
                //你可以根据自己所提供下载的文件类型，使用不同的响应 mime 类型
                response.setContentType("application/octet-stream;charset=utf-8");
                //设置下载弹出框中默认显示的文件名称，如果指定中文名称的话，需要转成 iso8859-1 编码，解决乱码问题
                fileName = new String(fileName.getBytes(), "iso8859-1");
                response.addHeader("Content-Disposition", "attachment;filename=" + fileName);
                IOUtils.write(bytes, response.getOutputStream());
            } catch (Exception ex) {
                ex.printStackTrace();
            }
        }
    }

    @ApiOperation("删除文件")
    @ApiImplicitParam(name = "minioPath",
            value = "minio文件路径（不包含web域名和bucket名称）", required = true)
    @PostMapping("/delete")
    public String deleteFile(String minioPath) {
        Boolean flag = minioService.deleteFile(minioPath);
        return flag ? "delete success" : "delete fail";
    }
}
